betty.test_utils.config.collections.sequence module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.config.collections.sequence module

Test utilities for `betty.config.collections.sequence`.

class betty.test_utils.config.collections.sequence.ConfigurationSequenceTestBase

  Bases: `Generic`[`_ConfigurationT`], `ConfigurationCollectionTestBase`[`int`, `_ConfigurationT`]

  A base class for testing `betty.config.collections.sequence.ConfigurationSequence` implementations.

  get_configuration_keys() → tuple[int, int, int, int]

    Produce four configuration keys to test the collection with.

  async test___iter__() → None

    Tests `betty.config.collections.ConfigurationCollection.__iter__()` implementations.